import blueBg from '@/assets/images/SecurityServiceOverview/right/blueBg.png';
import orangeBg from '@/assets/images/SecurityServiceOverview/right/orangeBg.png';
import redBg from '@/assets/images/SecurityServiceOverview/right/redBg.png';
import yellowBg from '@/assets/images/SecurityServiceOverview/right/yellowBg.png';
import risk4 from '@/assets/images/SecurityServiceOverview/risk/blue.png';
import risk2 from '@/assets/images/SecurityServiceOverview/risk/orange.png';
import risk1 from '@/assets/images/SecurityServiceOverview/risk/red.png';
import risk3 from '@/assets/images/SecurityServiceOverview/risk/yellow.png';
import CooglMap from '@/components/CooglMap';
import Modal from '@/components/HncyModal';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import services from '@/services';
import BMapService from '@/utils/mapService';
import { getColorByIndex } from '@/utils/ui';
import { useModel, useRequest } from '@umijs/max';
import { ConfigProvider, Flex, Space, Tree } from 'antd';
import classNames from 'classnames';
import React, { CSSProperties, useEffect, useRef, useState } from 'react';
import BaseInfo from '../../BaseInfo';
import styles from './index.less';
/** 地图 */
const DistrictMap: React.FC = () => {
  const [selected, setSelected] = useState<any>();
  const colorConfig: Record<
    string,
    {
      color: CSSProperties['color'];
      bg: string;
      icon: string;
    }
  > = {
    红色风险: {
      //红色风险
      color: '#FFBCBC',
      bg: redBg,
      icon: 'redIcon',
    },
    橙色风险: {
      //橙色风险
      color: '#FDDFCE',
      bg: orangeBg,
      icon: 'orangeIcon',
    },
    黄色风险: {
      //黄色风险
      color: '#FFE892',
      bg: yellowBg,
      icon: 'yellowIcon',
    },
    一般风险: {
      //一般风险
      color: '#BFE4FF',
      bg: blueBg,
      icon: 'blueIcon',
    },
  };
  /** @description store */

  const [checkedKeys, setCheckedKeys] = useState(['aq', 'cswt']);
  const MapRef = useRef<any>();
  const { selectDistrict, areaListDto, getIndexs, indexs } = useModel(
    'regionalIndex',
    (store) => ({
      areaListDto: store.areaListDto,
      selectDistrict: store.selectDistrict!,
      getIndexs: store.getIndexs,
      indexs: store.indexs,
    }),
  );
  // 事件详情弹窗
  const [detailModalOpt, setDetailModalOpt] = useState<any>({
    open: false,
    title: '',
    eventId: '',
  });
  /** 是否启用百度地图 */
  const [isBmap, setIsBmap] = useState(false);
  const [leftTabKey, setLeftTabKey] = useState('1');
  const [data, setData] = useState<any[]>([]);

  const { dispatch } = useGlobalModalServices();
  const [searchParams, setSearchParams] = useState({
    parentTypeCode: 'dlql',
    lat: 30.680193,
    lon: 104.075555,
    distance: 1000,
    page: 1,
    count: 100,
  });

  useEffect(() => {
    services.Physicalsign.getObjectPolygon({
      physicalSignType: 1,
      objectHierarchy: 1,
    }).then((res) => {
      setData(res.data);
    });

    //最新事件
    services.CityProblemApi.getUpToDateEvent({ page: 1, count: 3 }).then(
      (res) => {
        console.log('getUpToDateEvent', res);
      },
    );
  }, []);

  //safetyRiskEventMap
  const { data: warnMark } = useRequest(
    () => services.CityRiskApi.safetyRiskEventMap(searchParams),
    {
      refreshDeps: [searchParams],
    },
  );
  const iconList = {
    1: require('@/assets/images/wtIc.png'),
    2: require('@/assets/images/tuchuIc.png'),
    3: require('@/assets/images/tuchuIc.png'),
    4: require('@/assets/images/wtIc.png'),
    5: require('@/assets/images/tuchuIc.png'),
  };
  const pList = [
    {
      l: [103.87453593938976, 30.746739203687397],
      type: 1,
    },
    {
      l: [103.9541617397942, 30.735316951515046],
      type: 2,
    },
    {
      l: [103.87424848162657, 30.72240319350852],
      type: 3,
    },
    {
      l: [103.92455359018533, 30.71569728382409],
      type: 4,
    },
    {
      l: [103.87453593938976, 30.71569728382409],
      type: 5,
    },
  ];
  const eventList = [
    {
      img: require('@/assets/images/event/newEvent.png'),
      title: '道路不洁',
      time: 5,
    },
    {
      img: require('@/assets/images/event/newEvent.png'),
      title: '道路不洁',
      time: 5,
    },
    {
      img: require('@/assets/images/event/newEvent.png'),
      title: '道路不洁',
      time: 5,
    },
  ];
  /** 标题渲染 */
  const titleRender = () => {
    return (
      <Flex align="center" className={styles.modalTitle}>
        <div className={styles.title}>{detailModalOpt?.eventType}</div>
        <span
          className={styles.tag}
          style={{
            backgroundImage: `url(${
              colorConfig[detailModalOpt?.riskLevelName]?.bg
            })`,
            color: colorConfig[detailModalOpt?.riskLevelName]?.color,
          }}
        >
          {detailModalOpt?.riskLevelName}
        </span>
        <span className={styles.type}>{detailModalOpt?.position}</span>
      </Flex>
    );
  };

  return (
    <div className={styles.container}>
      <CooglMap.MapView
        zoom={13}
        ref={MapRef}
        center={{ x: 104.066349, y: 30.658842 }}
      >
        {leftTabKey === '1' ? (
          <>
            {data?.map((item, index) => {
              return (
                <CooglMap.Polygon
                  fillColor={getColorByIndex(Number(item.qualitySign))!}
                  key={index}
                  strokeColor="#fff"
                  points={item.points}
                  strokeWidth={2}
                  fillOpacity={0.2}
                ></CooglMap.Polygon>
              );
            })}
            {data?.map((item, index) => {
              const point = [Number(item.centerX), Number(item.centerY)];

              return (
                <CooglMap.CustomOverlay
                  key={index}
                  position={point}
                  onSet={() => {
                    console.log('hello world');
                    setSelected(item);
                    dispatch.push('districtIndex', {
                      title: item?.objectName + '运行情况',
                      props: {
                        data: item,
                        indexs: indexs,
                      },
                    });
                  }}
                >
                  <div
                    data-event-key="set"
                    className={styles.indexMarker}
                    style={
                      BMapService.getMakerCSS(
                        Number(item.qualitySign),
                      ) as CSSProperties
                    }
                  >
                    {Number(item.qualitySign)}
                  </div>
                </CooglMap.CustomOverlay>
              );
            })}
            {/* {selected && (
              <CooglMap.CustomOverlay
                position={[Number(selected.centerX), Number(selected.centerY)]}
                offset={{
                  top: -50,
                }}
                onClose={() => {
                  setSelected(undefined);
                }}
              >
                <div className={styles.window}>
                  <div className={styles.header}>
                    道路交通设施
                    <div data-event-key="close">
                      <CloseCircleOutlined />
                    </div>
                  </div>
                  <ConfigProvider
                    theme={{
                      components: {
                        Descriptions: {
                          itemPaddingBottom: 4,
                          titleColor: '#fff',
                          titleMarginBottom: 10,
                        },
                      },
                    }}
                  >
                    <div>2113131</div>
                  </ConfigProvider>
                </div>
              </CooglMap.CustomOverlay>
            )} */}
          </>
        ) : (
          <>
            {warnMark?.items?.map((item: any, index: number) => {
              const point = [Number(item?.x_pos), Number(item?.y_pos)];

              return (
                <CooglMap.CustomOverlay
                  key={index}
                  position={point}
                  onSet={() => {
                    setDetailModalOpt({
                      open: true,
                      eventId: item?.riskId,
                      ...item,
                    });
                  }}
                >
                  <img
                    data-event-key="set"
                    src={require(`@/assets/images/SecurityServiceOverview/right/${
                      colorConfig[item?.riskLevel]?.icon
                    }.png`)}
                    alt=""
                    style={{ width: 82, height: 82, zIndex: 999 }}
                  />
                </CooglMap.CustomOverlay>
              );
            })}
            {pList.map((item, index) => {
              return (
                <CooglMap.Marker
                  key={index}
                  onClick={() => {}}
                  position={item.l}
                  icon={(iconList as any)[index + 1]}
                ></CooglMap.Marker>
              );
            })}
          </>
        )}
      </CooglMap.MapView>

      {selectDistrict && (
        <div className={styles.districtName}>{selectDistrict.objectName}</div>
      )}
      <div className={styles.statusBar}>
        {/* <Space>
          <Switch onChange={setIsBmap}></Switch>
          <div>启用百度地图</div>
        </Space> */}
        <div className={styles.title}>图层图例</div>
        <div
          className={styles.leftTab}
          style={{ background: leftTabKey == '1' ? 'rgb(19, 146, 224)' : '' }}
          onClick={() => setLeftTabKey('1')}
        >
          CQI
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#F24F4F' }} />
          <div>应急态 &lt;60</div>
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#FFA81A' }} />
          <div>预警态 &lt;85</div>
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#00B9FF' }} />
          <div>标准态 85-95</div>
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#57EF58' }} />
          <div>理想态 &gt;95</div>
        </div>
        <div
          className={styles.leftTab}
          style={{ background: leftTabKey == '2' ? 'rgb(19, 146, 224)' : '' }}
          onClick={() => setLeftTabKey('2')}
        >
          风险预警与问题分布
        </div>
        {leftTabKey == '2' && (
          <ConfigProvider
            theme={{
              token: {},
              components: {
                Tree: {
                  directoryNodeSelectedBg: '#1b4761',
                },
              },
            }}
          >
            <Tree
              checkable
              defaultExpandAll
              onSelect={(e) => {
                console.log(e);
              }}
              onCheck={(e) => {
                setCheckedKeys(e);
              }}
              checkedKeys={checkedKeys}
              treeData={[
                {
                  title: '安全风险',
                  key: 'aq',
                  children: [
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk1}></img>红色风险
                        </div>
                      ),
                      key: 'aqh',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk2}></img>橙色风险
                        </div>
                      ),
                      key: 'anc',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk3}></img>黄色风险
                        </div>
                      ),
                      key: 'anh',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk4}></img>一般风险
                        </div>
                      ),

                      key: 'any',
                    },
                  ],
                },
                {
                  title: '城市问题',
                  key: 'cswt',
                  children: [
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={require('@/assets/images/wtIc.png')}></img>
                          未结案
                        </div>
                      ),
                      key: 'cswt1',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img
                            src={require('@/assets/images/tuchuIc.png')}
                          ></img>
                          突出问题
                        </div>
                      ),
                      key: 'cswt2',
                    },
                  ],
                },
              ]}
            />
          </ConfigProvider>
        )}
      </div>
      <div className={styles.leftWarp}>
        <div className={styles.warnWarp}>
          <Flex
            className={styles.warnItem}
            justify="center"
            vertical
            style={
              {
                '--color': colorConfig['红色风险']?.color,
                background: `url(${colorConfig['红色风险']?.bg})`,
                backgroundSize: '100% 100%',
              } as CSSProperties
            }
            onClick={() => {
              // setDetailModalOpt({
              //   open: true,
              //   eventId: it?.asriskId,
              //   ...it,
              // });
            }}
          >
            {colorConfig['红色风险']?.icon && (
              <img
                src={require(`@/assets/images/SecurityServiceOverview/right/${colorConfig['红色风险']?.icon}.png`)}
                className={styles.icon}
              />
            )}
            <div className={classNames(styles.title, 'textellipsis')}>
              广告设施用电不规范
            </div>
            <Space align="start">
              <span className={classNames(styles.address, 'textellipsis')}>
                成都市温江区人和...
              </span>
              <div className={styles.time}>3分钟前</div>
            </Space>
          </Flex>
        </div>
        <div className={styles.eventWarp}>
          <div className={styles.title}>最新事件</div>
          <div className={styles.listWarp}>
            {eventList?.map((item, index) => {
              return (
                <div key={'event_' + index} className={styles.items}>
                  <img src={item?.img} alt="" className={styles.img} />
                  <div className={styles.bottomWarp}>道路不洁</div>
                  <div className={styles.time}>{item.time}分钟前</div>
                </div>
              );
            })}
          </div>
          {/* <div className={styles.otherWarp}>
            <div className={styles.other}>更多</div>
          </div> */}
        </div>
      </div>
      {/* 事件详情 */}
      <Modal
        open={detailModalOpt?.open}
        titleRender={titleRender}
        onCancel={() => {
          setDetailModalOpt({
            open: false,
            title: '事件详情',
            eventId: '',
          });
        }}
        width={2650}
        height={900}
      >
        {detailModalOpt?.open && (
          <BaseInfo
            eventId={detailModalOpt?.eventId}
            detail={detailModalOpt}
            onChangeOpt={(val) => {
              console.log(val);

              setDetailModalOpt({
                ...detailModalOpt,
                position: val?.position,
                eventType: val?.event_type,
                riskLevelName: val?.risklevel,
              });
            }}
          />
        )}
      </Modal>
    </div>
  );
};

export default DistrictMap;
