import blueBg from '@/assets/images/SecurityServiceOverview/right/blueBg.png';
import orangeBg from '@/assets/images/SecurityServiceOverview/right/orangeBg.png';
import redBg from '@/assets/images/SecurityServiceOverview/right/redBg.png';
import yellowBg from '@/assets/images/SecurityServiceOverview/right/yellowBg.png';
import risk4 from '@/assets/images/SecurityServiceOverview/risk/blue.png';
import risk2 from '@/assets/images/SecurityServiceOverview/risk/orange.png';
import risk1 from '@/assets/images/SecurityServiceOverview/risk/red.png';
import risk3 from '@/assets/images/SecurityServiceOverview/risk/yellow.png';
import BMapView from '@/components/BMapView';
import CooglMap from '@/components/CooglMap';
import Modal from '@/components/HncyModal';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import services from '@/services';
import BMapService from '@/utils/mapService';
import { getColorByIndex, getCqiStatusStyle } from '@/utils/ui';
import { DownCircleFilled, UpCircleFilled } from '@ant-design/icons';
import { useRequest } from 'ahooks';
import { ConfigProvider, Flex, Space, Tree } from 'antd';
import React, { CSSProperties, useEffect, useRef, useState } from 'react';
import { CustomOverlay } from 'react-bmapgl';
import styles from './index.less';
import BaseInfo from '../../BaseInfo';
const EmphasisAreaMap: React.FC = () => {
  const colorConfig: Record<
    string,
    {
      color: CSSProperties['color'];
      bg: string;
      icon: string;
    }
  > = {
    红色风险: {
      //红色风险
      color: '#FFBCBC',
      bg: redBg,
      icon: 'redIcon',
    },
    橙色风险: {
      //橙色风险
      color: '#FDDFCE',
      bg: orangeBg,
      icon: 'orangeIcon',
    },
    黄色风险: {
      //黄色风险
      color: '#FFE892',
      bg: yellowBg,
      icon: 'yellowIcon',
    },
    一般风险: {
      //一般风险
      color: '#BFE4FF',
      bg: blueBg,
      icon: 'blueIcon',
    },
  };
  const [expand, setExpand] = useState<number>();
  const ref = useRef(0);
  const { dispatch } = useGlobalModalServices();
  /** 是否启用百度地图 */
  const [isBmap, setIsBmap] = useState(false);
  const MapRef = useRef<any>();
  const [leftTabKey, setLeftTabKey] = useState('1');
  const [checkedKeys, setCheckedKeys] = useState(['aq', 'cswt'])
  // 事件详情弹窗
  const [detailModalOpt, setDetailModalOpt] = useState<any>({
    open: false,
    title: '',
    eventId: '',
  });
  const [areaList, setAreaList] = useState<any>([])
  const [allAreaMapData, setAllAreaMapData] = useState<any>([])
  const [searchParams, setSearchParams] = useState({
    parentTypeCode: 'dlql',
    lat: 30.680193,
    lon: 104.075555,
    distance: 1000,
    page: 1,
    count: 100,
  });
  const data = [
    {
      name: '党政机关',
      num: 2,
      child: [
        {
          name: '市委市政府',
          value: 98.5,
        },
        {
          name: '市城管委',
          value: 78.5,
        },
      ],
    },
    {
      name: '交通场站',
      num: 6,
      child: [
        {
          name: '市委市政府',
          value: 98.5,
        },
        {
          name: '市城管委',
          value: 78.5,
        },
      ],
    },
    {
      name: '美丽街区',
      num: 6,
      child: [
        {
          name: '市委市政府',
          value: 98.5,
        },
        {
          name: '市城管委',
          value: 78.5,
        },
      ],
    },
  ];

  const p1 = [103.74243115816007, 30.79721665183887];

  const p2 = [104.48437948789275, 30.807638945537175];

  /**
   * @description 设置地图视野
   */
  const setViewport = () => {
    // const map = MapRef.current?.map as BMapGL.Map;
    // if (map) {
    //   map.setViewport([p1, p2]);
    // }
  };

  /** @description 移动视角到能显示全部覆盖物 */
  useEffect(() => {
    setViewport();
  }, [MapRef.current]);
  const { data: warnMark } = useRequest(
    () => services.CityRiskApi.safetyRiskEventMap(searchParams),
    {
      refreshDeps: [searchParams],
    },
  );
  const iconList = {
    1: require('@/assets/images/wtIc.png'),
    2: require('@/assets/images/tuchuIc.png'),
    3: require('@/assets/images/tuchuIc.png'),
    4: require('@/assets/images/wtIc.png'),
    5: require('@/assets/images/tuchuIc.png'),
  };

  // 重点区域列表
  const getImportantAreaList = async () => {
    const params = {
      physicalSignType: 1,
      objectHierarchy: 19
    }
    const res = await services.Physicalsign.getGroupObjectPhysicalSignIndex(params)
    console.log(res);
    if (res.code === 200) {
      setAreaList(res.data)
    }
  }

  useEffect(() => {
    getImportantAreaList()
  }, [])

  const pList = [
    {
      l: [103.87453593938976, 30.746739203687397],
      type: 1,
    },
    {
      l: [103.9541617397942, 30.735316951515046],
      type: 2,
    },
    {
      l: [103.87424848162657, 30.72240319350852],
      type: 3,
    },
    {
      l: [103.92455359018533, 30.71569728382409],
      type: 4,
    },
    {
      l: [103.87453593938976, 30.71569728382409],
      type: 5,
    },
  ];

  const getObjectPolygon = async () => {
    const params = {
      physicalSignType: 1,
      objectHierarchy: 19,
    }
    const res = await services.Physicalsign.getObjectPolygon(params)
    if (res.code === 200) {
      if (res.data?.length) {
        console.log(res.data)
        setAllAreaMapData(res.data)
      }
    }
  }

  useEffect(() => {
    getObjectPolygon()
  }, [])


  /** 标题渲染 */
  const titleRender = () => {
    return (
      <Flex align="center" className={styles.modalTitle}>
        <div className={styles.title}>{detailModalOpt?.eventType}</div>
        <span
          className={styles.tag}
          style={{
            backgroundImage: `url(${colorConfig[detailModalOpt?.riskLevelName]?.bg
              })`,
            color: colorConfig[detailModalOpt?.riskLevelName]?.color,
          }}
        >
          {detailModalOpt?.riskLevelName}
        </span>
        <span className={styles.type}>{detailModalOpt?.position}</span>
      </Flex>
    );
  };
  return (
    <div className={styles.container}>
      {isBmap ? (
        <BMapView
          zoom={13}
          ref={MapRef}
          style={{ width: '100%', height: '110%' }}
          center={new BMapGL.Point(104.066349, 30.658842)}
          onClick={(e) => console.log(e)}
        >
          <CustomOverlay position={BMapService.buildPoint(p1[0], p1[1])}>
            <div
              className={styles.indexMarker}
              onClick={(e) => {
                e.stopPropagation();

                dispatch.push('KeyAreaDetail', {
                  title: '市委市政府',
                });
              }}
            >
              <div className={styles.markerContent}>
                市委市政府<span style={{ color: getColorByIndex(89) }}>89</span>
              </div>
              <div
                className={styles.markerIcon}
                style={{ borderColor: getColorByIndex(89) }}
              ></div>
            </div>
          </CustomOverlay>
          <CustomOverlay position={BMapService.buildPoint(p2[0], p2[1])}>
            <div className={styles.indexMarker}>
              <div className={styles.markerContent}>
                市城管委
                <span style={{ color: getColorByIndex(98.5) }}>98.5</span>
              </div>
              <div
                className={styles.markerIcon}
                style={{ borderColor: getColorByIndex(98.5) }}
              ></div>
            </div>
          </CustomOverlay>
        </BMapView>
      ) : (
        <CooglMap.MapView
          zoom={13}
          ref={MapRef}
          boundingSpherePoints={[p1, p2]}
          center={{ x: 104.066349, y: 30.658842 }}
        >
          {leftTabKey === '1' ? (
            <>
              {/* <CooglMap.CustomOverlay
                position={p1}
                onClick={() => {
                  dispatch.push('KeyAreaDetail', {
                    title: '市委市政府',
                  });
                }}
                onSet={() => {
                  console.log('hello world');
                }}
              >
                <div
                  className={styles.indexMarker}
                  style={
                    {
                      '--b-color': getColorByIndex(89),
                    } as CSSProperties
                  }
                >
                  <div className={styles.markerContent} data-event-key="set">
                    市委市政府<span>89</span>
                  </div>
                  <div className={styles.markerIcon}></div>
                </div>
              </CooglMap.CustomOverlay>
              <CooglMap.CustomOverlay
                position={p2}
                onClick={() => {
                  dispatch.push('KeyAreaDetail', {
                    title: '城市管委',
                  });
                }}
              >
                <div className={styles.indexMarker}>
                  <div className={styles.markerContent}>
                    市城管委
                    <span style={{ color: getColorByIndex(98.5) }}>98.5</span>
                  </div>
                  <div
                    className={styles.markerIcon}
                    style={{ borderColor: getColorByIndex(98.5) }}
                  ></div>
                </div>
              </CooglMap.CustomOverlay> */}
              {
                allAreaMapData?.map((item: any) => (
                  <CooglMap.CustomOverlay
                    position={[item?.centerX, item?.centerY]}
                    onClick={() => {
                      dispatch.push('KeyAreaDetail', {
                        title: item.objectName,
                        props: {
                          objectId: item?.objectId,
                          cqi: item?.qualitySign,
                        },
                      });
                    }}
                    key={item.objectId}
                  >
                    <div className={styles.indexMarker}>
                      <div className={styles.markerContent}>
                        { item?.objectName }
                        <span style={{ color: getColorByIndex(item?.qualitySign) }}>{item?.qualitySign}</span>
                      </div>
                      <div
                        className={styles.markerIcon}
                        style={{ borderColor: getColorByIndex(item?.qualitySign) }}
                      ></div>
                    </div>
                  </CooglMap.CustomOverlay>
                ))
              }
            </>
          ) : (
            <>
              {warnMark?.data?.items?.map((item: any, index: number) => {
                const point = [Number(item?.x_pos), Number(item?.y_pos)];

                return (
                  <CooglMap.CustomOverlay
                    key={index}
                    position={point}
                    onSet={() => {
                      setDetailModalOpt({
                        open: true,
                        eventId: item?.riskId,
                        ...item,
                      });
                    }}
                  >
                    <img
                      data-event-key="set"
                      src={require(`@/assets/images/SecurityServiceOverview/right/${colorConfig[item?.riskLevel]?.icon
                        }.png`)}
                      alt=""
                      style={{ width: 82, height: 82, zIndex: 999 }}
                    />
                  </CooglMap.CustomOverlay>
                );
              })}
              {pList.map((item, index) => {
                return (
                  <CooglMap.Marker
                    key={index}
                    onClick={() => { }}
                    position={item.l}
                    icon={(iconList as any)[index + 1]}
                  ></CooglMap.Marker>
                );
              })}
            </>
          )}
        </CooglMap.MapView>
      )}

      <div className={styles.leftList}>
        <div className={styles.listTitle}>重点区域列表</div>
        <div>
          {areaList?.map((item, index) => {
            return (
              <div key={index}>
                <Flex
                  className={styles.listItem}
                  align="center"
                  justify="space-between"
                  onClick={() => {
                    if (expand === index) {
                      setExpand(undefined);
                      return;
                    }
                    ref.current = index;

                    setExpand(index);
                  }}
                >
                  <div>{item?.objGroup}</div>
                  <Space>
                    <div>{item?.objects?.length}</div>
                    <div>个</div>
                    {index === expand ? (
                      <UpCircleFilled style={{ color: '#1CC0FF' }} />
                    ) : (
                      <DownCircleFilled style={{ color: '#1CC0FF' }} />
                    )}
                  </Space>
                </Flex>
                {expand === index && (
                  <div className={styles.childWrap}>
                    {item?.objects.map((child, child_index) => {
                      return (
                        <Flex
                          key={child_index}
                          align="center"
                          className={styles.childItem}
                          justify="space-between"
                        >
                          <div>{child.objectName}</div>
                          <div style={{ color: getCqiStatusStyle(child.cqi)?.color }}>
                            {child.cqi}
                          </div>
                        </Flex>
                      );
                    })}
                  </div>
                )}
              </div>
            );
          })}
        </div>
      </div>

      <div className={styles.statusBar}>
        {/* <Space>
          <Switch onChange={setIsBmap}></Switch>
          <div>启用百度地图</div>
        </Space> */}
        <div className={styles.title}>图层图例</div>
        <div
          className={styles.leftTab}
          style={{ background: leftTabKey == '1' ? 'rgb(19, 146, 224)' : '' }}
          onClick={() => setLeftTabKey('1')}
        >
          CQI
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#F24F4F' }} />
          <div>应急态 &lt;60</div>
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#FFA81A' }} />
          <div>预警态 &lt;85</div>
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#00B9FF' }} />
          <div>标准态 85-95</div>
        </div>
        <div className={styles.itemWarp}>
          <div className={styles.mark} style={{ backgroundColor: '#57EF58' }} />
          <div>理想态 &gt;95</div>
        </div>
        <div
          className={styles.leftTab}
          style={{ background: leftTabKey == '2' ? 'rgb(19, 146, 224)' : '' }}
          onClick={() => setLeftTabKey('2')}
        >
          风险预警与问题分布
        </div>
        {leftTabKey == '2' && (
          <ConfigProvider
            theme={{
              token: {},
              components: {
                Tree: {
                  directoryNodeSelectedBg: '#1b4761',

                },
              },
            }}
          >
            <Tree
              checkable
              defaultExpandAll
              onSelect={(e) => {
                console.log(e);

              }}
              onCheck={(e) => {

                setCheckedKeys(e)
              }}
              checkedKeys={checkedKeys}
              treeData={[
                {
                  title: '安全风险',
                  key: 'aq',
                  children: [
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk1}></img>红色风险
                        </div>
                      ),
                      key: 'aqh',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk2}></img>橙色风险
                        </div>
                      ),
                      key: 'anc',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk3}></img>黄色风险
                        </div>
                      ),
                      key: 'anh',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={risk4}></img>一般风险
                        </div>
                      ),

                      key: 'any',
                    },
                  ],
                },
                {
                  title: '城市问题',
                  key: 'cswt',
                  children: [
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img src={require('@/assets/images/wtIc.png')}></img>
                          未结案
                        </div>
                      ),
                      key: 'cswt1',
                    },
                    {
                      title: (
                        <div className={styles.treeTitle}>
                          <img
                            src={require('@/assets/images/tuchuIc.png')}
                          ></img>
                          突出问题
                        </div>
                      ),
                      key: 'cswt2',
                    },
                  ],
                },
              ]}
            />
          </ConfigProvider>
        )}
      </div>
      {/* 事件详情 */}
      <Modal
        open={detailModalOpt?.open}
        titleRender={titleRender}
        onCancel={() => {
          setDetailModalOpt({
            open: false,
            title: '事件详情',
            eventId: '',
          });
        }}
        width={2650}
        height={900}
      >
        {detailModalOpt?.open && (
          <BaseInfo
            eventId={detailModalOpt?.eventId}
            detail={detailModalOpt}
            onChangeOpt={(val) => {
              console.log(val);

              setDetailModalOpt({
                ...detailModalOpt,
                position: val?.position,
                eventType: val?.event_type,
                riskLevelName: val?.risklevel,
              });
            }}
          />
        )}
      </Modal>
    </div>
  );
};

export default EmphasisAreaMap;
